Skip to contents

Plot a dist_fns S3 object

Usage

# S3 method for class 'dist_fns'
plot(x, ...)

Arguments

x

a dist_fns S3 object

...

Named arguments passed on to plot.dist_fns_list

x

a dist_fns_list

...

passed to ggplot2::geom_step,ggplot2::geom_rect or ggplot2::geom_area,

mapping

override default aesthetics with name, id or group

steps

resolution of the plot

tail

the minimum tail probability to plot

plot_quantiles

by default the quantiles of the distribution are plotted over the density sometimes this makes it hard to read

smooth

by default some additional smoothing is used to cover up small discontinuities in the PDF.

Value

a ggplot