Analogous to purrr::pmap_dbl()
Arguments
- .l
A list of vectors. The length of
.ldetermines the number of arguments that.fwill be called with. Arguments will be supply by position if unnamed, and by name if named.Vectors of length 1 will be recycled to any length; all other elements must be have the same length.
A data frame is an important special case of
.l. It will cause.fto be called once for each row.- .f
a function to apply to each
.litem (usually anas.link_fns()call)- ...
Additional arguments passed on to the mapped function.
We now generally recommend against using
...to pass additional (constant) arguments to.f. Instead use a shorthand anonymous function:# Instead of x |> map(f, 1, 2, collapse = ",") # do: x |> map(\(x) f(x, 1, 2, collapse = ","))This makes it easier to understand which arguments belong to which function and will tend to yield better error messages.
- .progress
Whether to show a progress bar. Use
TRUEto turn on a basic progress bar, use a string to give it a name, or see progress_bars for more details.