Skip to contents

This is a generated data set of an outbreak based on a branching process model with fixed parameters. There is a both the full infection line list as it happened in the simulation and the subset of this data that might have been observed in a contact tracing exercise where identification is done through symptoms.

Usage

sim_outbreak

Format

An object of class list of length 3.

Details

sim_outbreak is a named list with 3 items

ItemTypeDescription
parameterslist[dbl]the ground truth of the simulation parameters
outbreak_truthdf[outbreak_truth]*the full infection line list
contact_tracingdf[contact_tracing]*the "observed" contact tracing subset

df[outbreak_truth] dataframe with 663 rows and 11 columns

The simulation details

ColumnTypeDescription
timedblThe true time of infection
idintPerson unique id
generation_intervaldblThe time since infector's infection
infectorintThe unique id of the infector
generationdblWhich generation is this infection since the simulation start
symptomlglDid this person experience symptoms
symptom_delaydblHow long after infection were their symptoms?
symptom_timedblWhen? (from the simulation start)
observationlglWas this person detected (only if symptoms)
observation_delaydblHow long after symptoms were they observed?
observation_timedblWhen? (from the simulation start)

df[contact_tracing] dataframe with 663 rows and 4 columns

A minimal set of data that might be collected in a contact tracing exercise.

ColumnTypeDescription
idintUnique person id
contact_idintUnique id of infectious contact
onset_timeintTime of symptom onset (from the simulation start)
obs_timeintTime of observation (from the simulation start)