A class wrapping a single (or set) of parametrised distributions and provides access to the quantile, cumulative probability and random functions of that specific distribution. Parametrisation is handled on construction.
Usage
# S3 method for class 'character'
as.dist_fns(x, ...)
# S3 method for class '`function`'
as.dist_fns(x, ...)
# S3 method for class 'fitdist'
as.dist_fns(x, ...)
as.dist_fns(x, ...)Details
dist_fns and dist_fns_list objects support $ access for fields and @ access
for attributes. dist_fns_lists can be made with the c() or rep() functions,
or with the purrr style map functions, and they support subsetting.
Individual dist_fns members of dist_fns_lists can be accessed with [[.
Methods (by class)
as.dist_fns(character): Construct a distribution by nameas.dist_fns(`function`): From a statistical functionas.dist_fns(fitdist): From afitdistrplus::fitdistoutput