Weighted distribution function interpolation in a logit z space
Source:R/dist-empirical.R
dot-logit_z_interpolation.RdWeighted cumulative probabilities are mapped to a logit space, data is transformed to Z space (assumes support is -Inf..Inf). This does not use a link function and the resulting interpolation functions are not vectorised. Importance weighting is done during CDF construction. Prediction is done using a weighted linear interpolation of nearby points. Weighting for interpolation is a distance based gaussian kernel from data points to interpolation point. OOB interpolation is supported.
Arguments
- x
either a vector of samples from a distribution
Xor cut-offs for cumulative probabilities when combined withp- w
for data fits, a vector the same length as
xgiving the importance weight of each observation. This does not need to be normalised. There must be some non zero weights, and all must be finite.- bw
a bandwidth expressed in terms of the probability width, or proportion of observations.