Analogous to purrr::map2_dbl()
Arguments
- .x, .y
A pair of vectors, usually the same length. If not, a vector of length 1 will be recycled to the length of the other.
- .f
a function to apply to each
.x,.ypair that returns adist_fnsS3 object (usually anas.dist_fns()call)- ...
Additional arguments passed on to the mapped function.
We now generally recommend against using
...to pass additional (constant) arguments to.f. Instead use a shorthand anonymous function:# Instead of x |> map(f, 1, 2, collapse = ",") # do: x |> map(\(x) f(x, 1, 2, collapse = ","))This makes it easier to understand which arguments belong to which function and will tend to yield better error messages.
- .progress
Whether to show a progress bar. Use
TRUEto turn on a basic progress bar, use a string to give it a name, or see progress_bars for more details.