Plot a dist_fns S3 object
Usage
# S3 method for class 'dist_fns'
plot(x, ...)Arguments
- x
a
dist_fnsS3 object- ...
Named arguments passed on to
plot.dist_fns_listxa
dist_fns_list...passed to
ggplot2::geom_step,ggplot2::geom_rectorggplot2::geom_area,mappingoverride default aesthetics with
name,idorgroupstepsresolution of the plot
tailthe minimum tail probability to plot
plot_quantilesby default the quantiles of the distribution are plotted over the density sometimes this makes it hard to read
smoothby default some additional smoothing is used to cover up small discontinuities in the PDF.