Weighted standard deviation
Arguments
- x
either a vector of samples from a distribution
Xor cut-offs for cumulative probabilities when combined withp- w
for data fits, a vector the same length as
xgiving the importance weight of each observation. This does not need to be normalised. There must be some non zero weights, and all must be finite.- na.rm
remove NAs (default TRUE)